@@ -8,7 +8,7 @@
 #   A Perl Module Chain to faciliate the Creation and Modification
 #   of High-Quality "Portable Document Format (PDF)" Files.
 #
-#   Copyright 1999-2004 Alfred Reibenschuh <areibens@cpan.org>.
+#   Copyright 1999-2005 Alfred Reibenschuh <areibens@cpan.org>.
 #
 #=======================================================================
 #
@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: ExtGState.pm,v 1.6 2004/06/15 09:14:41 fredo Exp $
+#   $Id: ExtGState.pm,v 1.8 2005/03/14 22:01:06 fredo Exp $
 #
 #=======================================================================
 
@@ -44,9 +44,10 @@ BEGIN {
 
     @ISA = qw(PDF::API2::Resource);
 
-    ( $VERSION ) = '$Revision: 1.6 $' =~ /Revision: (\S+)\s/; # $Date: 2004/06/15 09:14:41 $
+    ( $VERSION ) = '$Revision: 1.8 $' =~ /Revision: (\S+)\s/; # $Date: 2005/03/14 22:01:06 $
 
 }
+no warnings qw[ deprecated recursion uninitialized ];
 
 =item $egs = PDF::API2::Resource::ExtGState->new @parameters
 
@@ -409,6 +410,12 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: ExtGState.pm,v $
+    Revision 1.8  2005/03/14 22:01:06  fredo
+    upd 2005
+
+    Revision 1.7  2004/12/16 00:30:53  fredo
+    added no warn for recursion
+
     Revision 1.6  2004/06/15 09:14:41  fredo
     removed cr+lf
 
