@@ -8,7 +8,7 @@
 #   A Perl Module Chain to faciliate the Creation and Modification
 #   of High-Quality "Portable Document Format (PDF)" Files.
 #
-#   Copyright 1999-2004 Alfred Reibenschuh <areibens@cpan.org>.
+#   Copyright 1999-2005 Alfred Reibenschuh <areibens@cpan.org>.
 #
 #=======================================================================
 #
@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: helveticabold.pm,v 1.5 2004/06/15 09:14:53 fredo Exp $
+#   $Id: helveticabold.pm,v 1.6 2005/03/14 22:01:29 fredo Exp $
 #
 #=======================================================================
 
@@ -551,6 +551,9 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: helveticabold.pm,v $
+    Revision 1.6  2005/03/14 22:01:29  fredo
+    upd 2005
+
     Revision 1.5  2004/06/15 09:14:53  fredo
     removed cr+lf
 
